@@ -24,12 +24,7 @@ TA builder needs to support:
 There are a lot of legacy codes here. If you want to see our changes,
 please search: ######## tab_update ########
 """
-
-from future import standard_library
-
-standard_library.install_aliases()
 import configparser
-from builtins import str
 
 try:
     from collections import OrderedDict as _default_dict
@@ -41,18 +36,18 @@ except ImportError:
 COMMENT_PREFIX = ";#*"
 COMMENT_KEY = "__COMMENTS__"
 
-class TABConfigParser(configparser.RawConfigParser):
 
+class TABConfigParser(configparser.RawConfigParser):
     def _read(self, fp, fpname):
         """
         Override the built-in _read() method to read comments
         """
         from configparser import DEFAULTSECT, ParsingError
 
-        cursect = None                        # None, or a dictionary
+        cursect = None  # None, or a dictionary
         optname = None
         lineno = 0
-        e = None                              # None, or an exception
+        e = None  # None, or an exception
 
         ######## tab_update ########
         comment_index = 0
@@ -68,10 +63,10 @@ class TABConfigParser(configparser.RawConfigParser):
             lineno = lineno + 1
             line = line.strip(" ")
             # comment or blank line?
-            if line.strip() == '' or line[0] in COMMENT_PREFIX:
+            if line.strip() == "" or line[0] in COMMENT_PREFIX:
 
-            ######## tab_update ########
-            # save the lineno & comments
+                ######## tab_update ########
+                # save the lineno & comments
                 if cursect:
                     name = "{}{}".format(COMMENT_KEY, comment_index)
                     comment_index += 1
@@ -81,7 +76,7 @@ class TABConfigParser(configparser.RawConfigParser):
                 continue
             ############################
 
-            if line.split(None, 1)[0].lower() == 'rem' and line[0] in "rR":
+            if line.split(None, 1)[0].lower() == "rem" and line[0] in "rR":
                 # no leading whitespace
                 continue
             # continuation line?
@@ -107,14 +102,14 @@ class TABConfigParser(configparser.RawConfigParser):
                 # is it a section header?
                 mo = self.SECTCRE.match(line)
                 if mo:
-                    sectname = mo.group('header')
+                    sectname = mo.group("header")
                     if sectname in self._sections:
                         cursect = self._sections[sectname]
                     elif sectname == DEFAULTSECT:
                         cursect = self._defaults
                     else:
                         cursect = self._dict()
-                        cursect['__name__'] = sectname
+                        cursect["__name__"] = sectname
                         self._sections[sectname] = cursect
                     # So sections can't start with a continuation line
                     optname = None
@@ -123,28 +118,28 @@ class TABConfigParser(configparser.RawConfigParser):
                 elif cursect is None:
                     ######## tab_update ########
                     # disable the exception since splunk allows the field outside stanzas
-#                     raise MissingSectionHeaderError(fpname, lineno, line)
+                    #                     raise MissingSectionHeaderError(fpname, lineno, line)
                     self.fields_outside_stanza.append(line)
                 ############################
                 # an option line?
                 else:
                     mo = self._optcre.match(line)
                     if mo:
-                        optname, vi, optval = mo.group('option', 'vi', 'value')
+                        optname, vi, optval = mo.group("option", "vi", "value")
                         optname = self.optionxform(optname.rstrip())
                         # This check is fine because the OPTCRE cannot
                         # match if it would set optval to None
                         if optval is not None:
-                            if vi in ('=', ':') and ';' in optval:
+                            if vi in ("=", ":") and ";" in optval:
                                 # ';' is a comment delimiter only if it follows
                                 # a spacing character
-                                pos = optval.find(';')
-                                if pos != -1 and optval[pos-1].isspace():
+                                pos = optval.find(";")
+                                if pos != -1 and optval[pos - 1].isspace():
                                     optval = optval[:pos]
                             optval = optval.strip()
                             # allow empty values
                             if optval == '""':
-                                optval = ''
+                                optval = ""
                             cursect[optname] = [optval]
                         else:
                             # valueless option handling
@@ -167,8 +162,7 @@ class TABConfigParser(configparser.RawConfigParser):
         for options in all_sections:
             for name, val in list(options.items()):
                 if isinstance(val, list):
-                    options[name] = '\n'.join(val)
-
+                    options[name] = "\n".join(val)
 
     def write(self, fp):
         """
@@ -189,7 +183,7 @@ class TABConfigParser(configparser.RawConfigParser):
         if self._defaults:
             fp.write("[%s]\n" % DEFAULTSECT)
             for (key, value) in list(self._defaults.items()):
-                fp.write("%s = %s\n" % (key, str(value).replace('\n', '\n\t')))
+                fp.write("{} = {}\n".format(key, str(value).replace("\n", "\n\t")))
             fp.write("\n")
         for section in self._sections:
             fp.write("[%s]\n" % section)
@@ -207,7 +201,7 @@ class TABConfigParser(configparser.RawConfigParser):
                 ############################
 
                 if (value is not None) or (self._optcre == self.OPTCRE):
-                    key = " = ".join((key, str(value).replace('\n', '\n\t')))
+                    key = " = ".join((key, str(value).replace("\n", "\n\t")))
                 fp.write("%s\n" % (key))
             ######## tab_update ########
             # write the seperator line for stanza
@@ -224,10 +218,10 @@ class TABConfigParser(configparser.RawConfigParser):
         items = configparser.RawConfigParser.items(self, section)
 
         res = []
-        for k,v in items:
+        for k, v in items:
             if k.startswith(COMMENT_KEY):
                 continue
-            res.append((k,v))
+            res.append((k, v))
         return res
 
     def options(self, section):
@@ -246,8 +240,12 @@ class TABConfigParser(configparser.RawConfigParser):
         sections = dict(self._sections)
         for section, key_values in list(sections.items()):
             kv = {}
-            for k,v in list(key_values.items()):
-                if not isinstance(k, str) or k.startswith(COMMENT_KEY) or k == "__name__":
+            for k, v in list(key_values.items()):
+                if (
+                    not isinstance(k, str)
+                    or k.startswith(COMMENT_KEY)
+                    or k == "__name__"
+                ):
                     continue
                 kv[k] = v
             if kv:
