@@ -27,15 +27,17 @@ from .alert_actions_merge import merge_conf_file
 
 
 def write_file(file_name, file_path, content, logger, merge="stanza_overwrite"):
-    logger.debug('operation="write", object="%s" object_type="file"',
-                 file_path)
+    logger.debug('operation="write", object="%s" object_type="file"', file_path)
 
     do_merge = False
-    if file_name.endswith('.conf') or file_name.endswith('conf.spec'):
+    if file_name.endswith(".conf") or file_name.endswith("conf.spec"):
         do_merge = True
     else:
-        logger.info('event="Will not merge file="%s", ' +
-                    'reason="Only support conf file merge"', file_path)
+        logger.info(
+            'event="Will not merge file="%s", '
+            + 'reason="Only support conf file merge"',
+            file_path,
+        )
 
     if file_path:
         new_file = None
@@ -43,7 +45,7 @@ def write_file(file_name, file_path, content, logger, merge="stanza_overwrite"):
             new_file = op.join(op.dirname(file_path), "new_" + file_name)
         if new_file:
             try:
-                with open(new_file, 'w+') as fhandler:
+                with open(new_file, "w+") as fhandler:
                     fhandler.write(content)
                 merge_conf_file(new_file, file_path, merge)
             finally:
@@ -52,29 +54,27 @@ def write_file(file_name, file_path, content, logger, merge="stanza_overwrite"):
         else:
             if not op.exists(op.dirname(file_path)):
                 makedirs(op.dirname(file_path))
-            with open(file_path, 'w+') as fhandler:
+            with open(file_path, "w+") as fhandler:
                 fhandler.write(content)
             if do_merge:
                 # need to process the file with conf parser
                 parser = TABConfigParser()
                 parser.read(file_path)
-                with open(file_path, 'w') as df:
+                with open(file_path, "w") as df:
                     parser.write(df)
     else:
-        sys.stdout.write("\n##################File {}##################\n".format(file_name))
+        sys.stdout.write(
+            "\n##################File {}##################\n".format(file_name)
+        )
         sys.stdout.write(content)
 
 
-GLOBAL_SETTING_TYPE_MAP = {
-    "text": "text",
-    "checkbox": "bool",
-    "password": "password"
-}
+GLOBAL_SETTING_TYPE_MAP = {"text": "text", "checkbox": "bool", "password": "password"}
 
 GLOBAL_SETTING_VALUE_NAME_MAP = {
     "text": "content",
     "bool": "bool",
-    "password": "password"
+    "password": "password",
 }
 
 
@@ -109,14 +109,15 @@ def convert_custom_setting(parameters):
     for param in parameters:
         if param.get("format_type") not in list(GLOBAL_SETTING_TYPE_MAP.keys()):
             msg = 'format_type="{}" is not support for global setting'.format(
-                param.get("format_type"))
+                param.get("format_type")
+            )
             raise Exception(msg)
 
         one_param = {
             "title": param.get("label"),
             "name": param.get("name"),
             "type": GLOBAL_SETTING_TYPE_MAP[param.get("format_type")],
-            "description": param.get("help_string")
+            "description": param.get("help_string"),
         }
         formated.append(one_param)
 
@@ -125,54 +126,54 @@ def convert_custom_setting(parameters):
 
 def convert_global_setting(global_settings):
     """
-    convert
-    {
-    "customized_settings": {
-        "string_label": {
-        "type": "text",
-        "content": "string"
-        },
-        "password": {
-        "type": "password",
-        "password": "123"
-        },
-        "checkbox": {
-        "type": "bool",
-        "bool": true
-        }
-    },
-    "proxy_settings": {
-        "proxy_password": "sef",
-        "proxy_type": "http",
-        "proxy_url": "1.2.3.4",
-    },
-    "global_settings": {
-        "log_level": "INFO"
-    }
-  to
-    {
-    "title": "Proxy",
-    "name": "proxy",
-    "type": "default_proxy",
-    "description": "proxy settings"
-    },
-    {
-    "title": "Account Key Title",
-    "name": "username",
-    "type": "default_account",
-    "description": "The username of the user account"
-    },
-    {
-    "title": "Account Secret Title",
-    "name": "password",
-    "type": "default_account",
-    "description": "The password of the user account"
-    },
-    {
-    "title": "customized key",
-    "name": "customized name",
-    "type": "text",
-    "description": "description of customized key"
+      convert
+      {
+      "customized_settings": {
+          "string_label": {
+          "type": "text",
+          "content": "string"
+          },
+          "password": {
+          "type": "password",
+          "password": "123"
+          },
+          "checkbox": {
+          "type": "bool",
+          "bool": true
+          }
+      },
+      "proxy_settings": {
+          "proxy_password": "sef",
+          "proxy_type": "http",
+          "proxy_url": "1.2.3.4",
+      },
+      "global_settings": {
+          "log_level": "INFO"
+      }
+    to
+      {
+      "title": "Proxy",
+      "name": "proxy",
+      "type": "default_proxy",
+      "description": "proxy settings"
+      },
+      {
+      "title": "Account Key Title",
+      "name": "username",
+      "type": "default_account",
+      "description": "The username of the user account"
+      },
+      {
+      "title": "Account Secret Title",
+      "name": "password",
+      "type": "default_account",
+      "description": "The password of the user account"
+      },
+      {
+      "title": "customized key",
+      "name": "customized name",
+      "type": "text",
+      "description": "description of customized key"
     """
     converted = []
     if not global_settings:
@@ -184,27 +185,30 @@ def convert_global_setting(global_settings):
                 "title": "Proxy",
                 "name": "proxy",
                 "type": "default_proxy",
-                "description": "proxy settings"}
+                "description": "proxy settings",
+            }
             converted.append(proxy)
         elif type == "log_settings":
             logging = {
                 "title": "Logging",
                 "name": "logging",
                 "type": "default_logging",
-                "description": "logging setting"}
+                "description": "logging setting",
+            }
             converted.append(logging)
         elif type == "credential_settings":
             username = {
                 "title": "Account Key Title",
                 "name": "tab_default_account_username",
                 "type": "default_account",
-                "description": "The username of the user account"
+                "description": "The username of the user account",
             }
             password = {
                 "title": "Account Secret Title",
                 "name": "tab_default_account_password",
                 "type": "default_account",
-                "description": "The password of the user account"}
+                "description": "The password of the user account",
+            }
             converted.append(username)
             converted.append(password)
         elif type == "customized_settings":
@@ -213,50 +217,49 @@ def convert_global_setting(global_settings):
     return converted
 
 
-
 def convert_global_setting_previous(global_settings):
     """
-    convert global_settings=[
+        convert global_settings=[
+            {
+                "type": "proxy"
+            },
+            {
+                "type": "logging"
+            },
+            {
+                "type": "account"
+            },
+            {
+                "type": "custom",
+                "parameters": []
+            }
+        ]
+            to [
         {
-            "type": "proxy"
+        "title": "Proxy",
+        "name": "proxy",
+        "type": "default_proxy",
+        "description": "proxy settings"
         },
         {
-            "type": "logging"
+        "title": "Account Key Title",
+        "name": "username",
+        "type": "default_account",
+        "description": "The username of the user account"
         },
         {
-            "type": "account"
+        "title": "Account Secret Title",
+        "name": "password",
+        "type": "default_account",
+        "description": "The password of the user account"
         },
         {
-            "type": "custom",
-            "parameters": []
+        "title": "customized key",
+        "name": "customized name",
+        "type": "text",
+        "description": "description of customized key"
         }
     ]
-        to [
-    {
-    "title": "Proxy",
-    "name": "proxy",
-    "type": "default_proxy",
-    "description": "proxy settings"
-    },
-    {
-    "title": "Account Key Title",
-    "name": "username",
-    "type": "default_account",
-    "description": "The username of the user account"
-    },
-    {
-    "title": "Account Secret Title",
-    "name": "password",
-    "type": "default_account",
-    "description": "The password of the user account"
-    },
-    {
-    "title": "customized key",
-    "name": "customized name",
-    "type": "text",
-    "description": "description of customized key"
-    }
-]
     """
     converted = []
     if not global_settings:
@@ -268,27 +271,30 @@ def convert_global_setting_previous(global_settings):
                 "title": "Proxy",
                 "name": "proxy",
                 "type": "default_proxy",
-                "description": "proxy settings"}
+                "description": "proxy settings",
+            }
             converted.append(proxy)
         elif setting.get("type") == "logging":
             logging = {
                 "title": "Logging",
                 "name": "logging",
                 "type": "default_logging",
-                "description": "logging setting"}
+                "description": "logging setting",
+            }
             converted.append(logging)
         elif setting.get("type") == "account":
             username = {
                 "title": "Account Key Title",
                 "name": "username",
                 "type": "default_account",
-                "description": "The username of the user account"
+                "description": "The username of the user account",
             }
             password = {
                 "title": "Account Secret Title",
                 "name": "password",
                 "type": "default_account",
-                "description": "The password of the user account"}
+                "description": "The password of the user account",
+            }
             converted.append(username)
             converted.append(password)
         elif setting.get("type") == "custom":
@@ -324,35 +330,35 @@ def get_parameter_type(param, parameters_meta, logger):
 
 def convert_test_global_settings(test_global_settings, logger):
     """
-    convert to:
-{
-  "customized_settings": {
-    "string_label": {
-      "type": "text",
-      "content": "string"
-    },
-    "password": {
-      "type": "password",
-      "password": "123"
-    },
-    "checkbox": {
-      "type": "bool",
-      "bool": true
+        convert to:
+    {
+      "customized_settings": {
+        "string_label": {
+          "type": "text",
+          "content": "string"
+        },
+        "password": {
+          "type": "password",
+          "password": "123"
+        },
+        "checkbox": {
+          "type": "bool",
+          "bool": true
+        }
+      },
+      "proxy_settings": {
+        "proxy_password": "sef",
+        "proxy_type": "http",
+        "proxy_url": "1.2.3.4",
+        "proxy_rdns": "0",
+        "proxy_username": "sdf",
+        "proxy_port": "34",
+        "proxy_enabled": "1"
+      },
+      "global_settings": {
+        "log_level": "INFO"
+      }
     }
-  },
-  "proxy_settings": {
-    "proxy_password": "sef",
-    "proxy_type": "http",
-    "proxy_url": "1.2.3.4",
-    "proxy_rdns": "0",
-    "proxy_username": "sdf",
-    "proxy_port": "34",
-    "proxy_enabled": "1"
-  },
-  "global_settings": {
-    "log_level": "INFO"
-  }
-}
     """
     if not test_global_settings:
         logger.info('test_global_settings="%s"', test_global_settings)
@@ -365,12 +371,12 @@ def convert_test_global_settings(test_global_settings, logger):
             for setting in settings:
                 type = get_test_parameter_type(setting)
                 if not type:
-                    msg = 'No type for {} in customized_settings'.format(setting)
+                    msg = "No type for {} in customized_settings".format(setting)
                     raise NotImplementedError(msg)
 
                 converted["customized_settings"][setting["name"]] = {
                     "type": type,
-                    GLOBAL_SETTING_VALUE_NAME_MAP[type]: setting.get("value")
+                    GLOBAL_SETTING_VALUE_NAME_MAP[type]: setting.get("value"),
                 }
         elif type == "log_settings":
             converted["global_settings"] = settings
